==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ast.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Avisos d'anovamientu",
    "Could not start updater, please try the manual update" : "Nun pudo aniciase l'anovador, por favor prueba l'anovamientu manual",
    "{version} is available. Get more information on how to update." : "Ta disponible {version}. Consigui más infromación tocante a cómo anovar.",
    "Channel updated" : "Anovóse la canal",
    "The update server could not be reached since %d days to check for new updates." : "Nun pudo algamase'l sirvidor d'anovamientu dende hai %d díes pa comprobar anovamientos.",
    "Please check the Nextcloud and server log files for errors." : "Comprueba los fallos de los ficheros de rexistru del sirvidor y Nextcloud, por favor.",
    "Update to %1$s is available." : "Ta disponible l'anovamientu a %1$s",
    "Update for %1$s to version %2$s is available." : "Ta disponible l'anovamientu pa %1$s a la versión %2$s.",
    "Update for {app} to version %s is available." : "Ta disponible l'anovamientu pa {app} a la versión %s.",
    "Update notification" : "Avisu d'anovamientu",
    "A new version is available: %s" : "Ta disponible una versión más nueva: %s",
    "Open updater" : "Abrir anovador",
    "Download now" : "Baxar agora",
    "Your version is up to date." : "La to versión ta anovada",
    "Checked on %s" : "Comprobóse'l %s",
    "Update channel:" : "Canal d'anovamientu:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Siempres pues anovar a una canal esperimental pero enxamás nun afites una canal más estable.",
    "Notify members of the following groups about available updates:" : "Avisar a los miembros de los grupos de darréu tocante a anovamientos disponibles:",
    "Only notification for app updates are available." : "Namái tán disponibles los avisos pa los anovamientos d'aplicaciones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La canal esbillada d'anovamientu fai avisos dedicaos pa lo obsoleto del sirvidor.",
    "The selected update channel does not support updates of the server." : "El canal esbilláu d'anovamientu nun sofita anovamientos del sirvidor."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ast.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Avisos d'anovamientu",
    "Could not start updater, please try the manual update" : "Nun pudo aniciase l'anovador, por favor prueba l'anovamientu manual",
    "{version} is available. Get more information on how to update." : "Ta disponible {version}. Consigui más infromación tocante a cómo anovar.",
    "Channel updated" : "Anovóse la canal",
    "The update server could not be reached since %d days to check for new updates." : "Nun pudo algamase'l sirvidor d'anovamientu dende hai %d díes pa comprobar anovamientos.",
    "Please check the Nextcloud and server log files for errors." : "Comprueba los fallos de los ficheros de rexistru del sirvidor y Nextcloud, por favor.",
    "Update to %1$s is available." : "Ta disponible l'anovamientu a %1$s",
    "Update for %1$s to version %2$s is available." : "Ta disponible l'anovamientu pa %1$s a la versión %2$s.",
    "Update for {app} to version %s is available." : "Ta disponible l'anovamientu pa {app} a la versión %s.",
    "A new version is available: %s" : "Ta disponible una versión más nueva: %s",
    "Open updater" : "Abrir anovador",
    "Download now" : "Baxar agora",
    "The update check is not yet finished. Please refresh the page." : "Entá nun finó la comprobación d'anovamientu. Refresca la páxina, por favor.",
    "Your version is up to date." : "La to versión ta anovada",
    "Checked on %s" : "Comprobóse'l %s",
    "Update channel:" : "Canal d'anovamientu:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Siempres pues anovar a una canal esperimental pero enxamás nun afites una canal más estable.",
    "Notify members of the following groups about available updates:" : "Avisar a los miembros de los grupos de darréu tocante a anovamientos disponibles:",
    "Only notification for app updates are available." : "Namái tán disponibles los avisos pa los anovamientos d'aplicaciones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La canal esbillada d'anovamientu fai avisos dedicaos pa lo obsoleto del sirvidor.",
    "The selected update channel does not support updates of the server." : "El canal esbilláu d'anovamientu nun sofita anovamientos del sirvidor."
},
"nplurals=2; plural=(n != 1);");
